@@ -27,6 +27,9 @@
  * Contributor(s): ______________________________________.
  *
  * $Log: gkserver.h,v $
+ * Revision 1.75  2004/03/31 07:16:22  csoutheren
+ * Added virtual to provide access to H.501 descriptor sent by GK
+ *
  * Revision 1.74  2004/02/15 03:36:30  rjongbloed
  * Fixed bug in removing prefixes, plus added ability to have multiple endpoints
  *   with the same profix, thanks Rossano Ravelli
@@ -1137,6 +1140,23 @@ class H323RegisteredEndPoint : public PSafeObject
     BOOL GetH225Version() const { return h225Version; }
   //@}
 
+  /**@name H.501 access functions */
+  //@{
+    /**
+      * Function called when gatekeeper sends a descriptor for this endpoint.
+      * This allows the gatekeeper to alter the descriptor information before
+      * it is sent.
+      *
+      * If returns FALSE then the desriptor is not sent
+      */
+      virtual BOOL OnSendDescriptorForEndpoint(
+        H225_ArrayOf_AliasAddress & aliases,          // aliases for the enndpoint
+        H225_EndpointType & terminalType,             // terminal type
+        H225_ArrayOf_AliasAddress & transportAddresses  // transport addresses
+      );
+  //@}
+
+
   protected:
     H323GatekeeperServer    & gatekeeper;
     H323GatekeeperListener  * rasChannel;
@@ -1853,6 +1873,16 @@ class H323GatekeeperServer : public H323TransactionServer
       const PString & alias
     );
 
+    // called when an endpoint needs to send a descriptor to the H.501 peer element
+
+    virtual BOOL OnSendDescriptorForEndpoint(
+      H323RegisteredEndPoint & /*ep*/,                    // endpoint
+      H225_ArrayOf_AliasAddress & /*aliases*/,            // aliases for the enndpoint
+      H225_EndpointType & /*terminalType*/,               // terminal type
+      H225_ArrayOf_AliasAddress & /*transportAddresses*/  // transport addresses
+    )
+    { return TRUE; } 
+
   protected:
 
     PDECLARE_NOTIFIER(PThread, H323GatekeeperServer, MonitorMain);
