@@ -27,6 +27,9 @@
  * Contributor(s): ______________________________________.
  *
  * $Log: h323caps.cxx,v $
+ * Revision 1.70  2004/03/24 01:57:20  csoutheren
+ * Updated for changes in H245v9
+ *
  * Revision 1.69  2004/03/02 11:48:17  rjongbloed
  * Fixed correct capability table matching when FindCapability with a mode change,
  *   uses different enum so needs translation table.
@@ -723,7 +726,7 @@ BOOL H323AudioCapability::OnSendingPDU(H245_DataType & dataType) const
 
 BOOL H323AudioCapability::OnSendingPDU(H245_ModeElement & mode) const
 {
-  mode.m_type.SetTag(H245_ModeElement_type::e_audioMode);
+  mode.m_type.SetTag(H245_ModeElementType::e_audioMode);
   return OnSendingPDU((H245_AudioMode &)mode);
 }
 
@@ -950,7 +953,7 @@ BOOL H323VideoCapability::OnSendingPDU(H245_DataType & dataType) const
 
 BOOL H323VideoCapability::OnSendingPDU(H245_ModeElement & mode) const
 {
-  mode.m_type.SetTag(H245_ModeElement_type::e_videoMode);
+  mode.m_type.SetTag(H245_ModeElementType::e_videoMode);
   return OnSendingPDU((H245_VideoMode &)mode.m_type);
 }
 
@@ -1101,7 +1104,7 @@ BOOL H323DataCapability::OnSendingPDU(H245_DataType & dataType) const
 
 BOOL H323DataCapability::OnSendingPDU(H245_ModeElement & mode) const
 {
-  mode.m_type.SetTag(H245_ModeElement_type::e_dataMode);
+  mode.m_type.SetTag(H245_ModeElementType::e_dataMode);
   H245_DataMode & type = mode.m_type;
   type.m_bitRate = maxBitRate;
   return OnSendingPDU(type);
@@ -1925,7 +1928,7 @@ H323Capability * H323Capabilities::FindCapability(const H245_ModeElement & modeE
   PTRACE(4, "H323\tFindCapability: " << modeElement.m_type.GetTagName());
 
   switch (modeElement.m_type.GetTag()) {
-    case H245_ModeElement_type::e_audioMode :
+    case H245_ModeElementType::e_audioMode :
       {
         const H245_AudioMode & audio = modeElement.m_type;
         static unsigned const AudioSubTypes[] = {
@@ -1955,7 +1958,7 @@ H323Capability * H323Capabilities::FindCapability(const H245_ModeElement & modeE
         return FindCapability(H323Capability::e_Audio, audio, AudioSubTypes);
       }
 
-    case H245_ModeElement_type::e_videoMode :
+    case H245_ModeElementType::e_videoMode :
       {
         const H245_VideoMode & video = modeElement.m_type;
         static unsigned const VideoSubTypes[] = {
@@ -1969,7 +1972,7 @@ H323Capability * H323Capabilities::FindCapability(const H245_ModeElement & modeE
         return FindCapability(H323Capability::e_Video, video, VideoSubTypes);
       }
 
-    case H245_ModeElement_type::e_dataMode :
+    case H245_ModeElementType::e_dataMode :
       {
         const H245_DataMode & data = modeElement.m_type;
         static unsigned const DataSubTypes[] = {
