@@ -24,6 +24,15 @@
  * Contributor(s): ______________________________________.
  *
  * $Log: peclient.cxx,v $
+ * Revision 1.42  2004/03/29 08:13:15  csoutheren
+ * Fixed problem with priorities
+ *
+ * Revision 1.41  2004/03/29 06:58:15  csoutheren
+ * Added extra trace messages
+ *
+ * Revision 1.40  2004/03/29 05:35:21  csoutheren
+ * Changed to use default address for descriptor if blank
+ *
  * Revision 1.39  2003/05/14 03:06:22  rjongbloed
  * Added another method for removing service relationships.
  * Added virtual for handling SR requests.
@@ -455,6 +464,8 @@ void H323PeerElement::UpdateAllDescriptors(PThread &, INT)
        )
       descriptor->state = H323PeerElementDescriptor::Deleted;
 
+    PTRACE(4, "PeerElement\tUpdating descriptor " << descriptor->descriptorID << " in state " << descriptor->state);
+
     UpdateDescriptor(descriptor);
   }
 
@@ -976,8 +987,10 @@ BOOL H323PeerElement::AddDescriptor(const OpalGloballyUniqueID & descriptorID,
       RemoveDescriptorInformation(descriptor->addressTemplates);
 
       // only update if the update time is later than what we already have
-      if (updateTime < descriptor->lastChanged)
+      if (updateTime < descriptor->lastChanged) {
+        PTRACE(4, "PeerElement\tNot updating descriptor " << descriptorID << " as " << updateTime << " < " << descriptor->lastChanged);
         return TRUE;
+      }
 
     } else {
       add = TRUE;
@@ -1166,6 +1179,7 @@ BOOL H323PeerElement::UpdateDescriptor(H323PeerElementDescriptor * descriptor, H
     descriptor->state = H323PeerElementDescriptor::Clean;
 
   for (PSafePtr<H323PeerElementServiceRelationship> sr = GetFirstRemoteServiceRelationship(PSafeReadOnly); sr != NULL; sr++) {
+    PTRACE(4, "PeerElement\tUpdating descriptor " << descriptor->descriptorID << " for service ID " << sr->serviceID);
     SendUpdateDescriptorByID(sr->serviceID, descriptor, updateType);
   }
 
@@ -1664,7 +1678,7 @@ BOOL H323PeerElementDescriptor::CopyToAddressTemplate(H501_AddressTemplate & add
   for (i = 0; i < transportAddresses.GetSize(); i++) {
     H501_ContactInformation & contact = contacts[i];
     contact.m_transportAddress = transportAddresses[i];
-    contact.m_priority         = 0;
+    contact.m_priority         = H323PeerElementDescriptor::GetPriorityOption(options);
   }
 
   // add protocols
